package com.akamai.ampaudiodemo;

import android.os.Bundle;
import android.support.v7.app.ActionBarActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;

import com.akamai.media.AMPLibraryInfo;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;

import java.util.Stack;


public class MainActivity extends ActionBarActivity implements IPlayerEventsListener {

    public Stack<String> streams;

    public VideoPlayerContainer mVideoContainer;

    public VideoPlayerView mVideoView;

    private Button btnSwitch;

    private final static String TAG = MainActivity.class.getSimpleName();

    private final static String LICENSE = "QpJHv679nYOslfq_CIn2a6EGd8VIHe_3VXnppglKToMhdPyUrsIkOVAMU4RHKjfDnICOuuIkFHoLgaZ5vnAHaA==";

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        streams = initStreams();

        // Get a reference to the VideoContainer object
        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);

        // Set the decoding mode used by the Android SDK video control
        mVideoContainer.setMode(VideoPlayerContainer.MODE_AUTOMATIC);
        Log.i(TAG, "MODE: " + mVideoContainer.getMode());

        // Get a reference to the VideoView object
        mVideoView = mVideoContainer.getAudioPlayer();

        // Set the IPlayerEventsListener implementation as the event listener
        mVideoView.setEventsListener(this);

        // Set your license
        mVideoView.setLicense(LICENSE);
        Log.i(TAG, "VERSION: " + AMPLibraryInfo.VERSION);

        btnSwitch = (Button) findViewById(R.id.btnSwitch);

        btnSwitch.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (mVideoView.isPlaying()) {
                    mVideoView.stop();
                }
                if (streams.size() == 0) {
                    Toast.makeText(MainActivity.this, "Reloading streams!", Toast.LENGTH_SHORT).show();
                    streams = initStreams();
                }
                String stream = streams.pop();
                mVideoView.playAudioUrl(stream);
                Toast.makeText(MainActivity.this, stream, Toast.LENGTH_SHORT).show();
            }
        });
    }

    private Stack<String> initStreams() {
        Stack<String> stack = new Stack<>();

        stack.push("http://raceview.b.nascar.com/hls_audio_testfeeds/whoknows/prog_index.m3u8");
        stack.push("http://raceview.b.nascar.com/hls_audio_testfeeds/perfidia/prog_index.m3u8");
        stack.push("http://raceview.b.nascar.com/hls_audio_testfeeds/karmapolice/prog_index.m3u8");
        stack.push("http://raceview.b.nascar.com/hls_audio_testfeeds/Fontana/radio/prog_index.m3u8");
        stack.push("http://ipv.wdr.de/metafiles/radio/wdr3/hls/wdr3.m3u8");

        return stack;
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return false;
    }

    @Override
    public boolean onPlayerEvent(int i) {
        Log.d(TAG, "onPlayerEvent: " + i);
        if (i == PLAYER_EVENT_TYPE_POSITION_UPDATE) {
                Log.d(TAG, "onPlayerEvent: POS: " + mVideoView.getTimePosition());
                Log.d(TAG, "onPlayerEvent: BITRATE: " + mVideoView.getCurrentBitrate());
        }

        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int i, int i2, int i3) {
        return false;
    }
}
